rtx-cfd legacy GPU: kernel outputs were device-buffer CLONES (every write lost) — the buffers are borrowed mutably now; the Poisson kernels keep boundary Dirichlet values; tests: the advection pulse marched 50 steps, the Jacobi budget 20k, the reduction reference in f64
CI / Python Bindings (maturin) (ubuntu-latest) (push) Blocked by required conditions
CI / Build (macos-latest) (push) Waiting to run
CI / Test (macos-latest) (push) Blocked by required conditions
CI / Test (ubuntu-latest) (push) Blocked by required conditions
CI / Python Bindings (maturin) (macos-latest) (push) Blocked by required conditions
CI / WASM Build + Size Check (push) Blocked by required conditions
CI / Distributed Training Tests (push) Blocked by required conditions
CI / CI Success (push) Blocked by required conditions
CI / Build CPU-Only (Explicit) (push) Failing after 5s
Documentation / Build User Guide (push) Successful in 5s
Documentation / Build API Documentation (push) Failing after 5s
CI / Format Check (push) Failing after 10s
CI / Build (ubuntu-latest) (push) Failing after 1m22s
CI / Clippy Check (push) Failing after 1m38s
Performance Benchmarks / Run Benchmarks (push) Successful in 2m50s

This commit is contained in:
Omar Sobh
2026-09-16 07:28:42 -05:00
parent f3f6ac21fb
commit 0de750bad1
8 changed files with 58 additions and 62 deletions
@@ -25,9 +25,9 @@ extern "C" __global__ void poisson_jacobi_2d(
int idx = j * nx + i;
// Boundary conditions (Dirichlet - zero on boundaries for now)
// Boundary cells keep the Dirichlet values they hold.
if (i == 0 || i == nx - 1 || j == 0 || j == ny - 1) {
phi_new[idx] = 0.0f;
phi_new[idx] = phi[idx];
return;
}
@@ -66,7 +66,6 @@ extern "C" __global__ void poisson_gauss_seidel_2d(
// Boundary conditions
if (i == 0 || i == nx - 1 || j == 0 || j == ny - 1) {
phi[idx] = 0.0f;
return;
}
@@ -105,7 +104,6 @@ extern "C" __global__ void poisson_sor_2d(
// Boundary conditions
if (i == 0 || i == nx - 1 || j == 0 || j == ny - 1) {
phi[idx] = 0.0f;
return;
}